/* 设备台账
 * @Author: Li Hanlin
 * @Date: 2022-11-10 09:39:56
 * @Last Modified by: Li Hanlin
 * @Last Modified time: 2022-11-21 17:38:29
 */

import * as React from 'react';
import { useState, useMemo, useRef, useEffect } from 'react';
import DrawerPro from '@/components/DrawerPro';
import AutoTable from '@/components/AutoTable';
import PremButton from '@/components/PremButton';
import getcolumns from './columns';
import { doFetch } from '@/utils/doFetch';
import { message, Dropdown, Menu, Layout, Button, Space, Divider, Tabs } from 'antd';
import TreeRender from '@/components/TreeRender';
import { ProDescriptions } from '@ant-design/pro-components';
import InitForm from '@/components/InitForm';

const { Sider, Content } = Layout;
function Model(props) {
  const actionRef = useRef(),
    formRef = useRef();
  const [drawer, setDrawer] = useState({
    visible: false,
  });

  const urlParams = {
    save: '/asset/equipment/save',
    remove: '/asset/equipment/deleteById',
    list: '/asset/equipment/queryList',
    detail: '/asset/equipment/detail',
  };

  const urlParams_childEquipment = {
    list: '/asset/equipment/children/queryList',
    checked: '/asset/equipment/children/selected/queryList',
    save: '/asset/equipmentChildren/save',
  };

  const urlParams_resume = {
    save: '/asset/equipmentLog/save',
  };

  const detail = (text, row, _, action) => {
    return (
      <PremButton
        btn={{
          size: 'small',
          type: 'link',
          onClick: () => {
            setDrawer((s) => ({
              ...s,
              visible: true,
              item: row,
              title: '详情',
              val: 'detail',
              title: row.userName + '的详细信息',
            }));
          },
        }}
      >
        详情
      </PremButton>
    );
  };

  const edit = (text, row, _, action) => {
    return (
      <PremButton
        btn={{
          size: 'small',
          onClick: () => {
            setDrawer((s) => ({
              ...s,
              visible: true,
              title: '编辑',
              val: 'edit',
              detailpath: urlParams.detail,
              params: { id: row.id },
              onFinish: async (vals) => {
                console.log(1);
                let params = {
                  ...vals,
                  id: row.id,
                };
                let res = await doFetch({
                  url: urlParams.save,
                  params,
                });
                if (res.code === '0000') {
                  message.success('新增成功！');
                  setDrawer((s) => ({
                    ...s,
                    visible: false,
                  }));
                  actionRef.current.reload();
                }
              },
            }));
          },
        }}
      >
        编辑
      </PremButton>
    );
  };

  const remove = (text, row, _, action) => {
    return (
      <PremButton
        pop={{
          title: '是否删除该设备?',
          okText: '确认',
          cancelText: '取消',
          onConfirm: async () => {
            let res = await doFetch({ url: urlParams.remove, params: { id: row.id } });
            if (res.code === '0000') {
              message.success('删除成功！');
              setDrawer((s) => ({
                ...s,
                visible: false,
              }));
              actionRef.current.reload();
            }
          },
        }}
        btn={{
          size: 'small',
          type: 'danger',
        }}
      >
        删除
      </PremButton>
    );
  };

  const more = (text, row, _, action) => {
    const menu = (
      <Menu
        items={[
          {
            label: (
              <a
                onClick={() => {
                  setDrawer((s) => ({
                    ...s,
                    visible: true,
                    type: 'editChildEquipment',
                    item: {
                      id: row.id,
                    },
                    val: 'only',
                    title: '编辑子设备',
                    // onFinish: async (vals) => {
                    //   console.log(1);
                    //   let params = {
                    //     ...vals,
                    //     id: row.id,
                    //   };
                    //   let res = await doFetch({
                    //     url: urlParams.save,
                    //     params,
                    //   });
                    //   if (res.code === '0000') {
                    //     message.success('新增成功！');
                    //     setDrawer((s) => ({
                    //       ...s,
                    //       visible: false,
                    //     }));
                    //     actionRef.current.reload();
                    //   }
                    // },
                  }));
                }}
              >
                编辑子设备
              </a>
            ),
            key: '0',
          },
          {
            label: (
              <a
                onClick={() => {
                  setDrawer((s) => ({
                    ...s,
                    visible: true,
                    type: 'resume',
                    item: {
                      id: row.id,
                    },
                    val: 'only',
                    title: '履历登记',
                    // onFinish: async (vals) => {
                    //   console.log(1);
                    //   let params = {
                    //     ...vals,
                    //     id: row.id,
                    //   };
                    //   let res = await doFetch({
                    //     url: urlParams.save,
                    //     params,
                    //   });
                    //   if (res.code === '0000') {
                    //     message.success('新增成功！');
                    //     setDrawer((s) => ({
                    //       ...s,
                    //       visible: false,
                    //     }));
                    //     actionRef.current.reload();
                    //   }
                    // },
                  }));
                }}
              >
                履历登记
              </a>
            ),
            key: '1',
          },
          {
            label: <a>关联备件(暂缓)</a>,
            key: '2',
          },
          {
            label: <a>寿命件台账(暂缓)</a>,
            key: '3',
          },
        ]}
      />
    );
    return (
      <Dropdown
        overlay={menu}
        trigger={['click']}
        arrow={true}
        getPopupContainer={() => document.getElementsByClassName('ant-table-content')[0]}
      >
        <Button size="small">更多</Button>
      </Dropdown>
    );
  };

  // 子设备
  const EditChildEquipment = () => {
    const [selectArr, setSelectArr] = useState([]);
    useEffect(() => {
      const fun = async () => {
        const result = await doFetch({
          url: '/asset/equipment/children/selected/queryList',
          params: { id: drawer?.item?.id },
        });
        // console.log(result);
        if (!result?.data?.dataList.length == 0) {
          setSelectArr(result?.data?.dataList.map((it) => it.id));
        }
      };
      fun();
    }, []);
    const columns = [
      {
        title: '设备编号',
        dataIndex: 'equipmentNo',
        key: 'equipmentNo',
        align: 'center',
        width: 120,
        formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
      },
      {
        title: '设备名称',
        dataIndex: 'equipmentName',
        align: 'center',
        width: 120,
        key: 'equipmentName',
        formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
      },
      {
        title: '公司名称',
        align: 'center',
        dataIndex: 'organizationName',
        width: 120,
        key: 'organizationId',
        valueType: 'select',
        options: { path: '/auth/sysDepartment/query/organization/selectbox', params: {} },
        formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
      },
      {
        title: '部门名称',
        width: 120,
        align: 'center',
        valueType: 'select',
        dataIndex: 'departmentName',
        key: 'departmentId',
        options: {
          path: '/auth/sysDepartment/query/depart/selectbox',
          linkParams: {
            organizationId: 'parentId',
          },
        },
      },
      {
        title: '工厂名称',
        dataIndex: 'factoryName',
        key: 'factoryId',
        width: 120,
        align: 'center',
        valueType: 'select',
        options: { path: '/auth/sysFactory/getAllFactorySelection', params: {} },
        formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
      },
      {
        title: '车间名称',
        dataIndex: 'shopName',
        align: 'center',
        width: 120,
        valueType: 'select',
        options: {
          path: '/auth/sysShop/getShopSelectionByFactory',
          linkParams: {
            factoryId: '',
          },
        },
        key: 'shopId',
        formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
      },
      {
        title: '工段名称',
        width: 120,
        dataIndex: 'sectionName',
        align: 'center',
        key: 'sectionId',
        valueType: 'select',
        options: {
          path: '/auth/sysSection/getAllSectionSelectionByShop',
          linkParams: {
            shopId: '',
          },
        },
      },
      {
        title: '产线名称',
        width: 120,
        dataIndex: 'productLineName',
        valueType: 'select',
        key: 'productLineName',
        align: 'center',
        options: {
          path: 'auth/sysProductionLine/getAllProductLineSelectionByShop',
          linkParams: {
            shopId: '',
          },
        },
      },
    ];
    return (
      <>
        <ProDescriptions
          request={async () => {
            const { data } = await doFetch({
              url: urlParams.detail,
              params: { id: drawer.item.id },
            });
            return {
              success: true,
              data: data.data,
            };
          }}
          columns={[
            {
              title: '设备编号',
              dataIndex: 'equipmentNo',
              key: 'equipmentNo',
            },
            {
              title: '设备名称',
              dataIndex: 'equipmentName',
              key: 'equipmentName',
            },
            {
              title: '位置号',
              dataIndex: 'positionNo',
              key: 'positionNo',
            },
            {
              title: '公司名称',
              dataIndex: 'organizationName',
              key: 'organizationId',
            },
            {
              title: '部门名称',
              dataIndex: 'departmentName',
              key: 'departmentId',
            },
            {
              title: '工厂名称',
              dataIndex: 'factoryName',
              key: 'factoryId',
            },
            {
              title: '车间名称',
              dataIndex: 'shopName',
              key: 'shopId',
            },
            {
              title: '工段名称',
              dataIndex: 'sectionName',
              key: 'sectionId',
            },
            {
              title: '产线名称',
              dataIndex: 'productLineName',
              key: 'productLineName',
            },
          ]}
        />
        <AutoTable
          pagetitle="选择子设备"
          columns={columns}
          path={urlParams_childEquipment.list}
          params={{ id: drawer?.item?.id }}
          resizeable={false}
          rowSelection={{
            type: 'checkbox',
            selectedRowKeys: selectArr,
            // defaultSelectedRowKeys: ,
            onSelect: (record, selected, selectedRows, nativeEvent) => {
              console.log('selectedRowKeys changed: ', record, selected, selectedRows);
              setSelectArr(() => {
                return selectedRows.map((it) => it.id);
              });
            },
            onSelectAll: (selected, selectedRows, changeRows) => {
              console.log(selected, selectedRows, changeRows);
              if (selected) {
                let arr = selectArr.concat(changeRows.map((it) => it.id));
                setSelectArr(arr);
              } else {
                setSelectArr([]);
              }
            },
            onSelectNone: () => {
              console.log(11);
              setSelectArr([]);
            },
          }}
        />
        <Space style={{ marginTop: 16 }}>
          <Button
            onClick={() => {
              console.log(drawer);
              setDrawer((s) => ({
                ...s,
                visible: false,
                item: null,
                detailpath: null,
                params: null,
                val: null,
                onFinish: null,
              }));
              setSelectArr([]);
            }}
          >
            取消
          </Button>
          <Button
            type="primary"
            onClick={async () => {
              console.log(selectArr);
              let res = await doFetch({
                url: urlParams_childEquipment.save,
                params: {
                  equipmentId: drawer?.item?.id,
                  childrenIdList: selectArr,
                },
              });
              if (res.code === '0000') {
                message.success('新增成功！');
                setDrawer((s) => ({
                  ...s,
                  visible: false,
                  item: null,
                }));
                setSelectArr([]);
                actionRef.current.reload();
              }
            }}
          >
            提交
          </Button>
        </Space>
      </>
    );
  };

  // 履历登记
  const Resume = () => {
    const [selectArr, setSelectArr] = useState([]);
    const [activeTab, setactiveTab] = useState(1);

    useEffect(() => {
      const fun = async () => {
        const result = await doFetch({
          url: '/asset/equipment/children/selected/queryList',
          params: { id: drawer?.item?.id },
        });
        // console.log(result);
        if (!result?.data?.dataList.length == 0) {
          setSelectArr(result?.data?.dataList.map((it) => it.id));
        }
      };
      fun();
    }, []);

    const fields = {
      1: [
        {
          title: '改造日期',
          dataIndex: 'reformDate',
          key: 'reformDate',
          valueType: 'date',
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '改造承包商',
          dataIndex: 'supplierId',
          key: 'supplierId',
          valueType: 'select',
          options: {
            path: '/asset/equipmentSupplier/query/selection',
            params: {},
          },
          formItemProps: {
            rules: [
              {
                required: true,
                message: '此项为必填项',
              },
            ],
          },
        },
        {
          title: '改造内容',
          dataIndex: 'reformContent',
          key: 'reformContent',
          valueType: 'textarea',
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '上传文件',
          key: 'urlIds ',
          valueType: 'uploadDragger',
          // colProps: { span: 24 },
          formItemProps: {
            rules: [
              {
                required: true,
                message: '此项为必填项',
              },
            ],
          },
        },
      ],
      2: [
        {
          title: '报废日期',
          dataIndex: 'scrapDate',
          key: 'scrapDate',
          valueType: 'date',
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '报废原因',
          dataIndex: 'scrapReason',
          key: 'scrapReason',
          valueType: 'textarea',
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '上传文件',
          key: 'urlIds ',
          valueType: 'uploadDragger',
          // colProps: { span: 24 },
          formItemProps: {
            rules: [
              {
                required: true,
                message: '此项为必填项',
              },
            ],
          },
        },
      ],
      3: [
        {
          title: '调入公司',
          dataIndex: 'organizationName',
          key: 'toOrganizationId',
          valueType: 'select',
          options: { path: '/auth/sysDepartment/query/organization/selectbox', params: {} },
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '调入部门',
          valueType: 'select',
          dataIndex: 'departmentName',
          key: 'toDepartmentId',
          options: {
            path: '/auth/sysDepartment/query/depart/selectbox',
            linkParams: {
              toOrganizationId: 'parentId',
            },
          },
        },
        {
          title: '调入工厂',
          dataIndex: 'factoryName',
          key: 'toFactoryId',
          valueType: 'select',
          options: { path: '/auth/sysFactory/getAllFactorySelection', params: {} },
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '调入车间',
          dataIndex: 'shopName',
          valueType: 'select',
          options: {
            path: '/auth/sysShop/getShopSelectionByFactory',
            linkParams: {
              toFactoryId: 'factoryId',
            },
          },
          key: 'toShopId',
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '调入工段',
          dataIndex: 'sectionName',
          key: 'toSectionId',
          valueType: 'select',
          options: {
            path: '/auth/sysSection/getAllSectionSelectionByShop',
            linkParams: {
              toShopId: 'shopId',
            },
          },
        },
        {
          title: '调入产线',
          dataIndex: 'productionLines',
          valueType: 'select',
          key: 'toProductLineId',
          options: {
            path: '/auth/sysProductionLine/getAllProductLineSelectionByShop',
            linkParams: {
              toShopId: 'shopId',
            },
          },
        },
        {
          title: '调入位置号',
          dataIndex: 'toPositionNo',
          valueType: 'input',
          key: 'toPositionNo',
        },
        {
          title: '调拨日期',
          dataIndex: 'transferDate',
          key: 'transferDate',
          valueType: 'date',
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '调拨原因',
          dataIndex: 'transferReason',
          key: 'transferReason',
          valueType: 'textarea',
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
      ],
      4: [
        {
          title: '借用公司',
          dataIndex: 'organizationName',
          key: 'toOrganizationId',
          valueType: 'select',
          options: { path: '/auth/sysDepartment/query/organization/selectbox', params: {} },
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '借用部门',
          valueType: 'select',
          dataIndex: 'departmentName',
          key: 'toDepartmentId',
          options: {
            path: '/auth/sysDepartment/query/depart/selectbox',
            linkParams: {
              toOrganizationId: 'parentId',
            },
          },
        },
        {
          title: '借用工厂',
          dataIndex: 'factoryName',
          key: 'toFactoryId',
          valueType: 'select',
          options: { path: '/auth/sysFactory/getAllFactorySelection', params: {} },
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '借用车间',
          dataIndex: 'shopName',
          valueType: 'select',
          options: {
            path: '/auth/sysShop/getShopSelectionByFactory',
            linkParams: {
              toFactoryId: 'factoryId',
            },
          },
          key: 'toShopId',
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '借用工段',
          dataIndex: 'sectionName',
          key: 'toSectionId',
          valueType: 'select',
          options: {
            path: '/auth/sysSection/getAllSectionSelectionByShop',
            linkParams: {
              toShopId: 'shopId',
            },
          },
        },
        {
          title: '借用产线',
          dataIndex: 'productionLines',
          valueType: 'select',
          key: 'toProductLineId',
          options: {
            path: '/auth/sysProductionLine/getAllProductLineSelectionByShop',
            linkParams: {
              toShopId: 'shopId',
            },
          },
        },
        {
          title: '借用位置号',
          dataIndex: 'toPositionNo',
          valueType: 'input',
          key: 'toPositionNo',
        },
        {
          title: '借用日期',
          dataIndex: 'borrowDate',
          key: 'borrowDate',
          valueType: 'date',
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '预计归还日期',
          dataIndex: 'planReturnDate',
          key: 'planReturnDate',
          valueType: 'date',
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
        {
          title: '借用原因',
          dataIndex: 'borrowReason',
          key: 'borrowReason',
          valueType: 'textarea',
          formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
        },
      ],
      5: [
        {
          title: '设备1',
          dataIndex: 'equipmentId',
          key: 'equipment',
        },
      ],
    };

    return (
      <>
        <ProDescriptions
          request={async () => {
            const { data } = await doFetch({
              url: urlParams.detail,
              params: { id: drawer?.item?.id },
            });
            return {
              success: true,
              data: data?.data,
            };
          }}
          columns={[
            {
              title: '设备编号',
              dataIndex: 'equipmentNo',
              key: 'equipmentNo',
            },
            {
              title: '设备名称',
              dataIndex: 'equipmentName',
              key: 'equipmentName',
            },
            {
              title: '位置号',
              dataIndex: 'positionNo',
              key: 'positionNo',
            },
            {
              title: '公司名称',
              dataIndex: 'organizationName',
              key: 'organizationId',
            },
            {
              title: '部门名称',
              dataIndex: 'departmentName',
              key: 'departmentId',
            },
            {
              title: '工厂名称',
              dataIndex: 'factoryName',
              key: 'factoryId',
            },
            {
              title: '车间名称',
              dataIndex: 'shopName',
              key: 'shopId',
            },
            {
              title: '工段名称',
              dataIndex: 'sectionName',
              key: 'sectionId',
            },
            {
              title: '产线名称',
              dataIndex: 'productLineName',
              key: 'productLineName',
            },
            {
              title: '供应商',
              dataIndex: 'supplierName',
              key: 'supplierId',
            },
            {
              title: '安装投产日期',
              dataIndex: 'productDate',
              key: 'productDate',
            },
          ]}
        />
        <Divider />

        <Tabs
          activeKey={activeTab}
          onChange={setactiveTab}
          items={[
            {
              label: '改造',
              key: 1,
              children: activeTab == 1 && (
                <InitForm
                  fields={fields[activeTab]}
                  onFinish={async (vals) => {
                    console.log(vals);
                    let res = await doFetch({
                      url: urlParams_resume.save,
                      params: { ...vals, type: '1', equipmentId: drawer?.item?.id },
                    });
                    if (res.code === '0000') {
                      message.success('登记成功！');
                      setDrawer((s) => ({
                        ...s,
                        visible: false,
                        item: null,
                      }));
                      actionRef.current.reload();
                    }
                  }}
                />
              ),
            }, // remember to pass the key prop
            {
              label: '报废',
              key: 2,
              children: activeTab == 2 && (
                <InitForm
                  fields={fields[activeTab]}
                  onFinish={async (vals) => {
                    console.log(vals);
                    let res = await doFetch({
                      url: urlParams_resume.save,
                      params: { ...vals, type: '2', equipmentId: drawer?.item?.id },
                    });
                    if (res.code === '0000') {
                      message.success('登记成功！');
                      setDrawer((s) => ({
                        ...s,
                        visible: false,
                        item: null,
                      }));
                      actionRef.current.reload();
                    }
                  }}
                />
              ),
            },
            {
              label: '调拨',
              key: 3,
              children: activeTab == 3 && (
                <InitForm
                  fields={fields[activeTab]}
                  onFinish={async (vals) => {
                    console.log(vals);
                    let res = await doFetch({
                      url: urlParams_resume.save,
                      params: { ...vals, type: '3', equipmentId: drawer?.item?.id },
                    });
                    if (res.code === '0000') {
                      message.success('登记成功！');
                      setDrawer((s) => ({
                        ...s,
                        visible: false,
                        item: null,
                      }));
                      actionRef.current.reload();
                    }
                  }}
                />
              ),
            },
            {
              label: '借用',
              key: 4,
              children: activeTab == 4 && (
                <InitForm
                  fields={fields[activeTab]}
                  onFinish={async (vals) => {
                    console.log(vals);
                    let res = await doFetch({
                      url: urlParams_resume.save,
                      params: { ...vals, type: '4', equipmentId: drawer?.item?.id },
                    });
                    if (res.code === '0000') {
                      message.success('登记成功！');
                      setDrawer((s) => ({
                        ...s,
                        visible: false,
                        item: null,
                      }));
                      actionRef.current.reload();
                    }
                  }}
                />
              ),
            },
            {
              label: '归还',
              key: 5,
              children: <InitForm fields={fields[activeTab]} />,
            },
          ]}
        />

        {/* <Space style={{ marginTop: 16 }}>
          <Button
            onClick={() => {
              console.log(drawer);
              setDrawer((s) => ({
                ...s,
                visible: false,
                item: null,
                detailpath: null,
                params: null,
                val: null,
                onFinish: null,
              }));
              setSelectArr([]);
            }}
          >
            取消
          </Button>
          <Button
            type="primary"
            onClick={async () => {
              console.log(selectArr);
              let res = await doFetch({
                url: urlParams_childEquipment.save,
                params: {
                  equipmentId: drawer?.item?.id,
                  childrenIdList: selectArr,
                },
              });
              if (res.code === '0000') {
                message.success('新增成功！');
                setDrawer((s) => ({
                  ...s,
                  visible: false,
                  item: null,
                }));
                setSelectArr([]);
                actionRef.current.reload();
              }
            }}
          >
            提交
          </Button>
        </Space> */}
      </>
    );
  };

  const columns = useMemo(() => {
    let defcolumn = getcolumns(setDrawer);
    defcolumn[1].render = (text, row) => {
      return (
        <a
          onClick={() => {
            setDrawer((s) => ({
              ...s,
              visible: true,
              // item: row,
              title: '详情',
              val: 'detail',
              detailpath: urlParams.detail,
              params: { id: row.id },
              title: row.equipmentName + '的详细信息',
            }));
          }}
        >
          {row.equipmentName}
        </a>
      );
    };
    return defcolumn.concat({
      title: '操作',
      valueType: 'option',
      fixed: 'right',
      width: 200,
      render: (text, row, _, action) => [
        edit(text, row, _, action),
        remove(text, row, _, action),
        more(text, row, _, action),
      ],
    });
  }, []);

  const onselecteTree = async (selectedKeys, e, alldata) => {
    console.log(e.node);
    let params = {
      treeNodeType: e.node.type,
      treeNodeKey: e.node.key,
      pageSize: 15,
      pageIndex: 1,
    };
    const res = await doFetch({ url: urlParams.list, params });
    if (res.code === '0000') {
      message.success('查询成功！');
      setDrawer((s) => ({
        ...s,
        visible: false,
      }));
    }
  };

  const selectMoreDrawerType = (type) => {
    switch (type) {
      case 'editChildEquipment':
        return <EditChildEquipment />;
      case 'resume':
        return <Resume />;
      default:
        return null;
    }
  };

  return (
    <div style={{ position: 'relative' }}>
      <div className="ant-card-head">
        <div className="ant-card-head-wrapper">
          <div className="ant-card-head-title">
            <h3 className="page-title">设备台账</h3>
          </div>
        </div>
      </div>
      <Layout style={{ height: '100%' }}>
        <Sider theme="light" width={300}>
          <TreeRender url="/auth/sysFactory/getTree" onselected={onselecteTree} noaction={true} />
        </Sider>
        <Content>
          <AutoTable
            pagetitle={<h3 style={{ marginBottom: 0, fontWeight: 400 }}>设备台账</h3>}
            columns={columns}
            path={urlParams.list}
            actionRef={actionRef}
            pageextra={'add'}
            resizeable={false}
            addconfig={{
              // access: 'sysDepartment_save',
              btn: {
                disabled: false,
                type: 'primary',
                onClick: () => {
                  setDrawer((s) => ({
                    ...s,
                    visible: true,
                    item: null,
                    title: '新增',
                    val: 'add',
                    onFinish: async (vals) => {
                      console.log(vals);
                      let params = {
                        ...vals,
                      };
                      let res = await doFetch({
                        url: urlParams.save,
                        params,
                      });
                      if (res.code === '0000') {
                        message.success('新增成功！');
                        setDrawer((s) => ({
                          ...s,
                          visible: false,
                        }));
                        actionRef.current.reload();
                      }
                    },
                  }));
                },
              },
            }}
            x={1500}
          />
        </Content>
      </Layout>
      <DrawerPro
        fields={columns}
        // detailpath="/ngic-auth/sysUser/query/detail"
        // params={{ id: drawer?.item?.id }}
        formRef={formRef}
        placement="right"
        onClose={() => {
          setDrawer((s) => ({
            ...s,
            visible: false,
            item: null,
            detailpath: null,
            params: null,
          }));
        }}
        {...drawer}
      >
        {selectMoreDrawerType(drawer?.type)}
      </DrawerPro>
    </div>
  );
}

export default Model;
